summaryrefslogtreecommitdiff
path: root/src/newgrf_callbacks.h
diff options
context:
space:
mode:
authorrubidium <rubidium@openttd.org>2011-12-15 21:56:00 +0000
committerrubidium <rubidium@openttd.org>2011-12-15 21:56:00 +0000
commit3d88c74389ec978bb198415816364898963bb979 (patch)
tree828173a0f2926b9082ff0ec1a08a293b213defba /src/newgrf_callbacks.h
parentdf0afdf0dca6b3d4f621248ada2aed73d7481c66 (diff)
downloadopenttd-3d88c74389ec978bb198415816364898963bb979.tar.xz
(svn r23526) -Codechange: unify cargos vs cargoes
Diffstat (limited to 'src/newgrf_callbacks.h')
-rw-r--r--src/newgrf_callbacks.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/newgrf_callbacks.h b/src/newgrf_callbacks.h
index 1cc608121..2290bd642 100644
--- a/src/newgrf_callbacks.h
+++ b/src/newgrf_callbacks.h
@@ -330,7 +330,7 @@ enum CanalCallbackMask {
};
/**
* Callback masks for cargos.
*/
enum CargoCallbackMask {
CBM_CARGO_PROFIT_CALC = 0, ///< custom profit calculation
@@ -353,8 +353,8 @@ enum IndustryCallbackMask {
CBM_IND_SPECIAL_EFFECT = 9, ///< control special effects
CBM_IND_REFUSE_CARGO = 10, ///< option out of accepting cargo
CBM_IND_DECIDE_COLOUR = 11, ///< give a custom colour to newly build industries
- CBM_IND_INPUT_CARGO_TYPES = 12, ///< customize the cargos the industry requires
- CBM_IND_OUTPUT_CARGO_TYPES = 13, ///< customize the cargos the industry produces
+ CBM_IND_INPUT_CARGO_TYPES = 12, ///< customize the cargoes the industry requires
+ CBM_IND_OUTPUT_CARGO_TYPES = 13, ///< customize the cargoes the industry produces
};
/**
@@ -330,7 +330,7 @@ enum CanalCallbackMask {
};
/**
- * Callback masks for cargos.
+ * Callback masks for cargoes.
*/
enum CargoCallbackMask {